@@ -1,13 +1,19 @@
 library(recipes)
 
+embeddings <- readRDS(test_path("emb-data", "embeddings.rds"))
+
+sentence_embeddings_long <- readRDS(test_path("emb-data", "long.rds"))
+sentence_embeddings_max <- readRDS(test_path("emb-data", "max.rds"))
+sentence_embeddings_mean <- readRDS(test_path("emb-data", "mean.rds"))
+sentence_embeddings_min <- readRDS(test_path("emb-data", "min.rds"))
+sentence_embeddings_sum <- readRDS(test_path("emb-data", "sum.rds"))
+
 eps <- if (capabilities("long.double")) {
   sqrt(.Machine$double.eps)
 } else {
   0.1
 }
 
-# Set up the data that will be used in these tests. -----------------------
-
 test_data <- tibble(text = c(
   "I would not eat them here or there.",
   "I would not eat them anywhere.",
@@ -17,90 +23,6 @@ test_data <- tibble(text = c(
 
 rec_base <- recipe(~., data = test_data)
 
-# Create some manual data for expected results.
-tokens <- rec_base %>%
-  step_tokenize(text) %>%
-  recipes::prep() %>%
-  recipes::bake(new_data = NULL) %>%
-  vctrs::vec_cbind(rename(test_data, text1 = text)) %>%
-  dplyr::select(text = text1, tokens = text)
-
-# Give each token an arbitrary value for comparison. Real embeddings will be
-# doubles, so make these double.
-embeddings <- tokens %>%
-  dplyr::mutate(tokens = vctrs::field(tokens, "tokens")) %>%
-  tidyr::unnest(tokens) %>%
-  dplyr::distinct(tokens) %>%
-  dplyr::arrange(tokens) %>%
-  # There are 17 unique tokens. We'll represent them with a 5-d set of vectors
-  # so each one can be unique.
-  dplyr::mutate(
-    token_num_binary = purrr::map(
-      seq_along(tokens),
-      function(this_token) {
-        tibble(
-          dimension = paste0("d", 1:5),
-          score = as.double(intToBits(this_token)[1:5])
-        )
-      }
-    )
-  ) %>%
-  tidyr::unnest(token_num_binary) %>%
-  tidyr::pivot_wider(
-    names_from = dimension,
-    values_from = score
-  )
-
-sentence_embeddings_long <- tokens %>%
-  dplyr::mutate(tokens = vctrs::field(tokens, "tokens")) %>%
-  tidyr::unnest(tokens) %>%
-  dplyr::left_join(embeddings, by = "tokens")
-
-# Summarize by each statistic, and reorder to original order.
-sentence_embeddings_sum <- sentence_embeddings_long %>%
-  dplyr::select(-tokens) %>%
-  dplyr::group_by(text) %>%
-  dplyr::summarize_all(sum) %>%
-  dplyr::rename_if(
-    is.numeric,
-    ~ paste("wordembed_text", ., sep = "_")
-  )
-sentence_embeddings_sum <- test_data %>%
-  dplyr::left_join(sentence_embeddings_sum, by = "text")
-
-sentence_embeddings_mean <- sentence_embeddings_long %>%
-  dplyr::select(-tokens) %>%
-  dplyr::group_by(text) %>%
-  dplyr::summarize_all(mean) %>%
-  dplyr::rename_if(
-    is.numeric,
-    ~ paste("wordembed_text", ., sep = "_")
-  )
-sentence_embeddings_mean <- test_data %>%
-  dplyr::left_join(sentence_embeddings_mean, by = "text")
-
-sentence_embeddings_min <- sentence_embeddings_long %>%
-  dplyr::select(-tokens) %>%
-  dplyr::group_by(text) %>%
-  dplyr::summarize_all(min) %>%
-  dplyr::rename_if(
-    is.numeric,
-    ~ paste("wordembed_text", ., sep = "_")
-  )
-sentence_embeddings_min <- test_data %>%
-  dplyr::left_join(sentence_embeddings_min, by = "text")
-
-sentence_embeddings_max <- sentence_embeddings_long %>%
-  dplyr::select(-tokens) %>%
-  dplyr::group_by(text) %>%
-  dplyr::summarize_all(max) %>%
-  dplyr::rename_if(
-    is.numeric,
-    ~ paste("wordembed_text", ., sep = "_")
-  )
-sentence_embeddings_max <- test_data %>%
-  dplyr::left_join(sentence_embeddings_max, by = "text")
-
 rec <- rec_base %>%
   step_tokenize(text) %>%
   step_word_embeddings(text, embeddings = embeddings)
@@ -210,11 +132,6 @@ test_that("step_word_embeddings deals with missing words appropriately.", {
     bake(obj, new_data = new_text),
     NA
   )
-  expect_warning(
-    bake(obj, new_data = new_text),
-    NA
-  )
-
   expect_warning(
     bake(obj, new_data = test_data),
     NA
